#!/bin/sh
#
# Retrieve recent data from the Weatherstation DB and pass to Ploticus to create image files...
#

# Rainfall

mkdir -p tmp_longterm
cd tmp_longterm

echo; echo; echo RAINFALL..
../get_rainfall_data.php "12 months" "1 month" >rainfalldata.txt
/usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 \
	 title="Rainfall" titledet="adjust=0,-0.20" xgrid=yes ygrid=yes xlbl="Month" ylbl="Rain (mm)" \
	 data=rainfalldata.txt header=no unittype=date mode=bars yrange=0 \
	 tab=month tabmode=mid  color=oceanblue datefmt=mm/dd/yyyy x=1 y=2 xinc="1 month" xmargin=0  \
	 barwidth=0.33 legendfmt=multiline   \
	 xrange="`date -v -11m "+%m/01/%G"` \
`date -v +1m "+%m/01/%G"`" \
> rainfall.png

#	 xrange="`cut -f1 -d\  rainfalldata.txt | head -n 1` \
#                `cut -f1 -d\  rainfalldata.txt | tail -n 1`" \

# outdoor air temp / dewpoint / ground temp
echo; echo; echo OUTDOOR...
../getdata.php outdoor  temperature  8 "Temp"      \
              dewpoint dewpointtemp 8 "Dewpoint"  \
              outdoor  temperature  a "Soil_10cm" \
              "365" "days" \
| /usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 -maxrows 1500000 -maxfields 1500000 -maxvector 1500000  \
 title="Outdoor Temperatures and Dew Point" titledet="adjust=0,-0.20"    \
 xlbl="Month" xinc="1 month" ylbl="Temp (deg. C)" xgrid=yes ygrid=yes data=- header=yes unittype=date mode=line  \
 datefmt=mm/dd/yyyy  legendfmt=singleline gapmissing=yes x=datetime  \
 y=2    y2=3      y3=4  \
 ptselect="@5 = A"   ptselect2="@5 = B"     ptselect3="@5 = C"  \
 linedet="color=green"  linedet2="color=oceanblue width=0.1" linedet3="color=claret width=0.1"  \
 ynearest=5 \
> outdoor-dewpoint.png

echo ; echo ; echo "PRESSURE.."
# Barometic Pressure
../getdata.php indoor  pressure     na "Pressure" \
              "365" "days" \
| /usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 -maxrows 1500000 -maxfields 1500000 -maxvector 1500000  \
 title="Pressure" titledet="adjust=0,-0.20"    \
 xlbl="Month" ylbl="Pressure (hPa)" xgrid=yes ygrid=yes data=- header=no unittype=date mode=line  \
 datefmt=mm/dd/yyyy xinc="1 month" legendfmt=multiline gapmissing=yes x=1 y=2 linedet="color=green"    \
 ynearest=5 yrange="970 1040" \
> pressure.png

echo ; echo ; echo "WIND.."
# Windspeed
../getdata.php wind speed na "Speed" \
              "365" "days" \
| /usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 -maxrows 1500000 -maxfields 1500000 -maxvector 1500000  \
 title="Windspeed" titledet="adjust=0,-0.20"    \
 xlbl="Month" ylbl="Speed (km/h)" xgrid=yes ygrid=yes data=- header=no unittype=date mode=line  \
 datefmt=mm/dd/yyyy xinc="1 month" legendfmt=multiline gapmissing=yes x=1 y=2 linedet="color=green"    \
 ynearest=5  \
> windspeed.png

../build_longterm_html_page.php > index.shtml

/bin/chmod ogu+r *.png *.shtml
/usr/bin/time scp -B *.png weatherstation@webserver:/weather/longterm
/usr/bin/time scp -B index.shtml weatherstation@webserver:/weather/longterm
