#!/bin/sh
#
# Retrieve recent data from the Weatherstation DB and pass to Ploticus to create image files...
#

# Rainfall

mkdir scripts/tmp
cd scripts/tmp

../get_rainfall_data.php "7 days" "1 day" >rainfalldata.txt
/usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 \
	 title="Rainfall" titledet="adjust=0,-0.20" xgrid=yes ygrid=yes xlbl="Day" ylbl="Rain (mm)" \
	 data=rainfalldata.txt header=no unittype=datetime mode=bars yrange=0 \
	 tab=day tabmode=mid color=oceanblue datefmt=mm/dd/yyyy x=1 y=2 xinc="1 day" \
	 legendfmt=multiline \
	 xrange="`date -v -7d "+%m/%d/%G"` \
`date -v +1d "+%m/%d/%G"`" \
> rainfall.png

#	 xrange="`cut -f1 -d\  rainfalldata.txt | head -n 1` \
#                `cut -f1 -d\  rainfalldata.txt | tail -n 1`" \

# outdoor air temp / dewpoint / ground temp
../getdata.php outdoor  temperature  8 "Temp"      \
              dewpoint dewpointtemp 8 "Dewpoint"  \
              outdoor  temperature  a "Soil_10cm" \
              "7" "days" \
| /usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 -maxrows 50000  \
 title="Outdoor Temperatures and Dew Point" titledet="adjust=0,-0.20"    \
 xlbl="Day" ylbl="Temp (deg. C)" xgrid=yes ygrid=yes data=- header=yes unittype=datetime mode=line  \
 datefmt=mm/dd/yyyy xinc="1 day" legendfmt=singleline gapmissing=yes x=datetime  \
 y=2    y2=3      y3=4  \
 ptselect="@5 = A"   ptselect2="@5 = B"     ptselect3="@5 = C"  \
 linedet="color=green"  linedet2="color=oceanblue width=0.1" linedet3="color=claret width=0.1"  \
 ynearest=5 \
> outdoor-dewpoint.png

# Barometic Pressure
../getdata.php indoor  pressure     na "Pressure" \
              "7" "days" \
| /usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 -maxrows 50000  \
 title="Pressure" titledet="adjust=0,-0.20"    \
 xlbl="Day" ylbl="Pressure (hPa)" xgrid=yes ygrid=yes data=- header=no unittype=datetime mode=line  \
 datefmt=mm/dd/yyyy xinc="1 day" legendfmt=multiline gapmissing=yes x=1 y=2 linedet="color=green"    \
 ynearest=5 yrange="970 1040" \
> pressure.png

# Windspeed
../getdata.php wind speed na "Speed" \
              "7" "days" \
| /usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 -maxrows 50000  \
 title="Windspeed" titledet="adjust=0,-0.20"    \
 xlbl="Day" ylbl="Speed (km/h)" xgrid=yes ygrid=yes data=- header=no unittype=datetime mode=line  \
 datefmt=mm/dd/yyyy xinc="1 day" legendfmt=multiline gapmissing=yes x=1 y=2 linedet="color=green"    \
 ynearest=5  \
> windspeed.png

# Wind direction
../getdata.php wind direction na "Speed" \
              "7" "days" \
| /usr/local/bin/pl -o stdout -png -prefab chron -scale 1.20 -maxrows 50000  \
 title="Wind Direction" titledet="adjust=0,-0.20"    \
 xlbl="Day" ylbl="Direction (deg)" xgrid=yes ygrid=yes data=- header=no unittype=datetime mode=line  \
 datefmt=mm/dd/yyyy xinc="1 day" legendfmt=multiline gapmissing=yes x=1 y=2 linedet="color=green"    \
 yinc=30  yrange="0 360" \
> windirection.png

../build_html_page.php > index.shtml

/bin/chmod ogu+r *.png *.shtml
/usr/bin/time scp -B *.png weatherstation@webserver:/weather
/usr/bin/time scp -B index.shtml weatherstation@webserver:/weather
