#!/usr/local/bin/php
<?php
// get_rainfall_data.php - Retrieve rainfall data for plotting
//
// Invoked from the shell.
//
// Usage:   "get_rainfall_data.php <duration> <time_interval>"
// Example: "get_rainfall_data.php "36 hours" "1 hour"

debug("start..");

$dbcon=pg_connect(get_db_connect_string());
if (!$dbcon) 
  barf("DB Connect Error");

if ($argc!=3)
  barf("incorrect arg count");

$duration        = $argv[1];
$time_interval   = $argv[2];
print_rainfall_data($dbcon, $duration, $time_interval);

debug("end.");
exit(0);



function time_to_sql($time)
{
	// return time as SQL-compatible ASCII: e.g. "2003-10-18 21:09:30"
	return strftime("%Y-%m-%d %H:%M", $time);
};

function print_rainfall_data($dbcon, $duration, $time_interval)
{
// Print to stdout, a table like this showing rainfall per TIME_INTERVAL over DURATION intervals up to now...
//     	datetime rainfall
// 	01/05/2004.14:45 18.5
// 	01/06/2004.03:03 19.9
// 	01/06/2004.09:11 22.5
//
// Example: print_rainfall_data($dbcon, "7 days", "1 day")

	debug("DURATION: ". $duration);
	debug("TIME INTERVAL: ". $time_interval);

	// Calculate Unix timestamps for start and stop times...
	$time 		= strtotime("-" . $duration);			// start at $start_time prior to now
	$stop_time	= strtotime("now"); // "+" . $duration, $time);		// stop at start time + duration

	debug("APPROX START TIME: ". $time);
	debug("STOPTIME: " . $stop_time);

	// print the header, plus the rain (zero) at the start of the first time interval...
	// print "datetime rainfall\n";
	//print strftime("%m/%d/%Y.%H:%M", $time) . " 0.0\n" ;

	// Read rain total at start of the period...

	// ** HACK ** Need to get back to start of the hour (if time interval is "1 hour") 
	//            or start of the day (if time interval is "1 day")
	// i.e. we need to go back and start at the top of the hour or day ...
	$temp = getdate($time);
	if ($time_interval == "1 hour")
	{
		$time = strtotime("-" . $temp["minutes"] . " minutes", $time);
		$time = strtotime("-" . $temp["seconds"] . " seconds", $time);
	}
	else
	{
		// assume days
		$time = strtotime("-" . $temp["hours"]   . " hours",   $time);
		$time = strtotime("-" . $temp["minutes"] . " minutes", $time);
		$time = strtotime("-" . $temp["seconds"] . " seconds", $time);

               	if ($time_interval == "1 month")
		{
			// go back to start of month..
			$time = strtotime("-" . $time["days"] . " days", $time);
			$time = strtotime("+ 2 days", $time);
		};
	};

	$query = "SELECT rainfall from rain where datetime = (SELECT min(datetime) from rain where datetime >= '" . time_to_sql($time) . "' AT TIME ZONE 'UTC' )" ;
	debug( "FIRST " . $query ) ;

	if ($row = pg_fetch_row(pg_query($dbcon, $query)))
		$last_rain_total = $row[0];
	else
		return;		// error - no data

	// Display output row for each time interval in the range...
	while (true)
	{
		$interval_end_time = strtotime(" + " . $time_interval, $time);	// bump on the timestamp

		// Read the rain total and subtract, to find rain that fell during this interval
		$query = "SELECT rainfall from rain where datetime = (SELECT min(datetime) from rain where datetime >= '" . time_to_sql($interval_end_time) . "' AT TIME ZONE 'UTC' )";
		debug( "LOOP: " . $query ) ;
		if ($row = pg_fetch_row(pg_query($dbcon,$query)))
		{
			$rain = $row[0] - $last_rain_total;
			print strftime("%m/%d/%Y.%H:%M", $time) . " " . ($rain * 1000) . "\n" ;
			$last_rain_total += $rain;
		}
		else
		{
			// HACK!  Stick an extra row in the output based on rain value right now.
			// Read the rain total and subtract, to find rain that fell during this PARTIAL interval
			$query = "SELECT rainfall from rain where datetime = (SELECT max(datetime) from rain)";
			error_log( "END1: " . $query ) ;
			if ($row = pg_fetch_row(pg_query($dbcon,$query)))
			{
				$rain = $row[0] - $last_rain_total;
				//$now = strtotime("now");
				//print strftime("%m/%d/%Y.%H:%M", $now) . " " . ($rain * 1000) . "\n" ;
				print strftime("%m/%d/%Y.00:00", $time) . " " . ($rain * 1000) . "\n" ;
				$last_rain_total += $rain;
			}
			return;		// no more data
		};
		$time = $interval_end_time;  // next interval starts where this one ended
	};
};

function barf($msg)
{
  flush();
  global $argv;
  error_log($argv[0] . ": FATAL: " . $msg);
  exit(1);
};

function debug($msg)
{
  flush();
  global $argv;
  error_log($argv[0] . ": " . $msg);
};

function get_db_connect_string()
{
  return "dbname=weatherdb user=weatherdbuser password=weatherdbpass";
};


?>
