#!/usr/local/bin/php
<?php

// ******************************************
// getdata.php - retrieve weather data (one to four columns) and print in ASCII to stdout
//
// Must be invoked from the shell - not from PHP or HTTP
//
// Usage:   getdata.php <table1> <field1> <addr1> <label1> 
//             [<table2> <field2> <addr2> <label2> [<table3> <field3> <addr3> <label3> [<table4><field3><addr4><label4>]]]
//           <time> <units>
//
// Examples:
//
//  getdata.php outdoor temperature 8  "outdoor" "7" "days"  
//
//  getdata.php outdoor temperature 8  "outdoor" outdoor temperature 9 "indoor" "7" "days" 

debug("starting...");

// valid arg count: 1 + 4 + 2 = 7, or 1 + 8 + 2 = 11, or 1 + 12 + 2 = 15, or 1 + 16 + 2 = 19

$table1 = "";
$table2 = "";
$table3 = "";
$table4 = "";

if ($argc == 7)
{
  $table1  = $argv[1];
  $field1  = $argv[2];
  $addr1   = $argv[3];
  $label1  = $argv[4];
  $time    = $argv[5];
  $units   = $argv[6];
}
else if ($argc == 11)
{
  $table1  = $argv[1];
  $field1  = $argv[2];
  $addr1   = $argv[3];
  $label1  = $argv[4];
  $table2  = $argv[5];
  $field2  = $argv[6];
  $addr2   = $argv[7];
  $label2  = $argv[8];
  $time    = $argv[9];
  $units   = $argv[10];
}
else if ($argc == 15)
{
  $table1  = $argv[1];
  $field1  = $argv[2];
  $addr1   = $argv[3];
  $label1  = $argv[4];
  $table2  = $argv[5];
  $field2  = $argv[6];
  $addr2   = $argv[7];
  $label2  = $argv[8];
  $table3  = $argv[9];
  $field3  = $argv[10];
  $addr3   = $argv[11];
  $label3  = $argv[12];
  $time    = $argv[13];
  $units   = $argv[14];
}
else if ($argc == 19)
{
  $table1  = $argv[1];
  $field1  = $argv[2];
  $addr1   = $argv[3];
  $label1  = $argv[4];
  $table2  = $argv[5];
  $field2  = $argv[6];
  $addr2   = $argv[7];
  $label2  = $argv[8];
  $table3  = $argv[9];
  $field3  = $argv[10];
  $addr3   = $argv[11];
  $label3  = $argv[12];
  $table4  = $argv[13];
  $field4  = $argv[14];
  $addr4   = $argv[15];
  $label4  = $argv[16];
  $time    = $argv[17];
  $units   = $argv[18];
}
else
  barf("incorrect arg count");

$dbcon=pg_connect(get_db_connect_string());
if (!$dbcon) 
  barf("pg_connect failed to connect to database");

// output data format:
// datetime label1 label2 label3 dataset
// 01/05/2004.14:45 18.5 0 0 A
// 01/06/2004.03:03 19.9 0 0 A
// 01/06/2004.09:11 22.5 0 0 A
// 01/05/2004.14:45 0 18.5 0 B
// 01/06/2004.03:03 0 19.9 0 B
// 01/06/2004.09:11 0 22.5 0 B
// 01/05/2004.14:45 0 0 18.5 C
// 01/06/2004.03:03 0 0 19.9 C
// 01/06/2004.09:11 0 0 22.5 C

if ($table2 == "")
{
  print("datetime " . $label1 . "\n");
  do_query_for_dataset($dbcon, 	"A", 	"", 		"" , 	$table1, $field1, $addr1, $time, $units);
}
else
if ($table3 == "")
{
  print("datetime " . $label1 . " " . $label2 . " dataset\n");
  do_query_for_dataset($dbcon, 	"A", 	"", 		"0 " , 	$table1, $field1, $addr1, $time, $units);
  do_query_for_dataset($dbcon, 	"B", 	"0 ", 		" " , 		$table2, $field2, $addr2, $time, $units);
}
else
if ($table4 == "")
{
  print("datetime " . $label1 . " " . $label2 . " " . $label3 . " dataset\n");
  do_query_for_dataset($dbcon, 	"A", 	"", 		"0 0 " , 	$table1, $field1, $addr1, $time, $units);
  do_query_for_dataset($dbcon, 	"B", 	"0 ", 		"0 " , 		$table2, $field2, $addr2, $time, $units);
  do_query_for_dataset($dbcon, 	"C", 	"0 0 ", 	"" , 		$table3, $field3, $addr3, $time, $units);
}
else
{
  print("datetime " . $label1 . " " . $label2 . " " . $label3 . " " . $label4 . " dataset\n");
  do_query_for_dataset($dbcon, 	"A", 	"", 		"0 0 0 " , 	$table1, $field1, $addr1, $time, $units);
  do_query_for_dataset($dbcon, 	"B", 	"0 ", 		"0 0 " , 	$table2, $field2, $addr2, $time, $units);
  do_query_for_dataset($dbcon, 	"C", 	"0 0 ", 	"0 " , 		$table3, $field3, $addr3, $time, $units);
  do_query_for_dataset($dbcon, 	"D", 	"0 0 0 ", 	"" , 		$table4, $field4, $addr4, $time, $units);
};

pg_close($dbcon);

debug("terminating cleanly.");
exit(0);



function do_query_for_dataset($dbcon, $dataset, $pre, $post, $table, $field, $addr, $time, $units)
{
  $query = "SELECT  datetime AT TIME ZONE 'UTC', " . $field . " FROM " . $table . " " .
           "WHERE datetime > NOW() AT TIME ZONE 'UTC' - interval '" .
  $time . " " . $units . "'";
  if ($addr != "na")
     $query = $query . " AND address = '" . $addr . "'" ;
  $query = $query . " ORDER BY datetime " ;

  debug($query);

  $result=pg_query($dbcon, $query);
  if ($result==FALSE)
    barf("pg_query failed to execute SELECT query");

  debug("Number of rows in result = " . pg_num_rows($result)) ;
  $i = 0;
  while ($row = pg_fetch_row($result))
  {
    $datetime = $row[0];
    $value    = $row[1];

    // conversions from SI units to display values
    if ($field == "speed")
       $value *= 3.6;	// m/s to km/h
    else
    if ($field == "pressure")
        $value *= 100;	// Pa to hPa

    if ($pre=="" && $post=="")
      print  strftime("%m/%d/%Y.%H:%M",strtotime($datetime)) . " " . $value . " \n";
    else
      print  strftime("%m/%d/%Y.%H:%M",strtotime($datetime)) . " " . $pre . $value . " " . $post . $dataset . "\n";
  };
};


function barf($msg)
{
  flush();
  global $argv;
  error_log($argv[0] . ": FATAL: " . $msg);
  exit(1);
};

function debug($msg)
{
  flush();
  global $argv;
  error_log($argv[0] . ": " . $msg);
};

function get_db_connect_string()
{
  return "dbname=weatherdb user=weatherdbuser password=weatherdbpass";
};



?>

